// eslint-disable-next-line import/no-extraneous-dependencies
import { useCallback, useMemo, useRef, useState } from 'react';
export function useLoaderApi() {
  const {
    current: loaders
  } = useRef(new Set());
  const [isLoading, setIsLoading] = useState(false);
  const reevaluate = useCallback(() => {
    // setState hook does not trigger re-render
    // unless value differs
    setIsLoading(loaders.size > 0);
  }, [loaders]);
  const api = useMemo(() => ({
    isActive: id => loaders.has(id),
    update: (id, value) => {
      const res = value ? !!loaders.add(id) : loaders.delete(id);
      reevaluate();
      return res;
    },
    remove: id => {
      const res = loaders.delete(id);
      reevaluate();
      return res;
    }
  }), [loaders, reevaluate]);
  return [api, isLoading];
}