import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
const _excluded = ["className", "frameClass", "language", "children", "codeSandbox"];
// eslint-disable-next-line import/no-extraneous-dependencies
import React, { useMemo, useState, useEffect, useRef } from 'react';
import classNames from 'classnames';
import copy from 'copy-to-clipboard';
import { IconCodeSandbox } from '@arco-design/web-react/icon';
import { SyntaxHighlighter } from "../../../baseUI/highlighter";
import styles from "./codeSnippet.module.scss";
import IconCopy from "../asset/icon-copy.svg";
import IconCheck from "../asset/icon-check.svg";
import IconShrink from "../asset/icon-shrink.svg";
import IconExpand from "../asset/icon-expand.svg";
const customStyles = {
  fontSize: 12
};
/**
 * A code snippet component
 */
export function CodeSnippet(_ref) {
  let {
      className,
      frameClass,
      language = 'tsx',
      children,
      codeSandbox
    } = _ref,
    rest = _objectWithoutProperties(_ref, _excluded);
  const [codeCopied, setCodeCopied] = useState(false);
  const [codeExpanded, setCodeExpanded] = useState(false);
  const refResetCopyStatusTimer = useRef(null);
  const trimmedChildren = useMemo(() => children.trim(), [children]);
  useEffect(() => {
    clearTimeout(refResetCopyStatusTimer.current);
    refResetCopyStatusTimer.current = setTimeout(() => {
      setCodeCopied(false);
    }, 1000);
  }, [codeCopied]);
  useEffect(() => {
    return () => {
      clearTimeout(refResetCopyStatusTimer.current);
    };
  }, []);
  const demoContext = window.arcoDemoContext;
  return /*#__PURE__*/React.createElement("div", {
    className: classNames(styles.snippetWrapper, className)
  }, /*#__PURE__*/React.createElement(SyntaxHighlighter, _extends({}, rest, {
    className: classNames(styles.codeSnippet, frameClass, {
      [styles.expanded]: codeExpanded
    }),
    language: language,
    customStyle: customStyles
  }), trimmedChildren), /*#__PURE__*/React.createElement("div", {
    className: styles.operationButtons
  }, codeSandbox && typeof (demoContext === null || demoContext === void 0 ? void 0 : demoContext.gotoCodeSandbox) === 'function' ? /*#__PURE__*/React.createElement("button", {
    onClick: () => demoContext === null || demoContext === void 0 ? void 0 : demoContext.gotoCodeSandbox({
      code: trimmedChildren,
      language
    })
  }, /*#__PURE__*/React.createElement(IconCodeSandbox, null)) : null, /*#__PURE__*/React.createElement("button", {
    onClick: () => {
      const result = copy(children.toString());
      setCodeCopied(result);
    }
  }, codeCopied ? /*#__PURE__*/React.createElement(IconCheck, null) : /*#__PURE__*/React.createElement(IconCopy, null)), /*#__PURE__*/React.createElement("button", {
    onClick: () => setCodeExpanded(!codeExpanded)
  }, codeExpanded ? /*#__PURE__*/React.createElement(IconShrink, null) : /*#__PURE__*/React.createElement(IconExpand, null))));
}