// eslint-disable-next-line import/no-extraneous-dependencies
import React, { useContext, useMemo, useState } from 'react';
// eslint-disable-next-line import/no-extraneous-dependencies
import { Link } from 'react-router-dom';
import cs from 'classnames';
import { Divider, Input, Tree } from '@arco-design/web-react';
import { IconApps, IconSearch } from '@arco-design/web-react/icon';
import { WorkspaceContext } from "../../workspaceContext";
import IconFolder from "../assets/folder.svg";
import IconFolderOpen from "../assets/folder-open.svg";
import IconFile from "../assets/file.svg";
import styles from "./componentMenu.module.scss";
export function ComponentMenu({
  componentId,
  onComponentChange
}) {
  const {
    components
  } = useContext(WorkspaceContext);
  const [filterText, setFilterText] = useState('');
  const routeInfo = useMemo(() => {
    const results = [];
    const groupByPackage = [];
    for (const component of components.sort((comA, comB) => comA.id > comB.id ? 1 : -1)) {
      let group = groupByPackage.find(node => node.package === component.packageName);
      if (!group) {
        group = {
          package: component.packageName,
          components: []
        };
        groupByPackage.push(group);
      }
      group.components.push(component);
    }
    for (const {
      package: packageName,
      components
    } of groupByPackage) {
      const getMenuItemProps = component => {
        const {
          id,
          name
        } = component;
        return {
          key: id,
          title: name
        };
      };
      const filterRule = ({
        key,
        title
      }) => {
        const _searchText = filterText.toLowerCase();
        return filterText ? key.toLowerCase().indexOf(_searchText) > -1 || title.toLowerCase().indexOf(_searchText) > -1 : true;
      };
      if (components.length > 1) {
        const children = components.map(getMenuItemProps).filter(filterRule);
        children.length && results.push({
          key: packageName,
          title: packageName,
          children
        });
      } else if (components.length) {
        const routeInfo = getMenuItemProps(components[0]);
        const filterResult = filterRule(routeInfo);
        filterResult && results.push(routeInfo);
      }
    }
    return results;
  }, [filterText]);
  return /*#__PURE__*/React.createElement("div", {
    className: styles.componentMenu
  }, /*#__PURE__*/React.createElement(Link, {
    className: cs(styles.overview, {
      [styles.active]: !componentId
    }),
    to: "/"
  }, /*#__PURE__*/React.createElement(IconApps, null), "Overview"), /*#__PURE__*/React.createElement(Input, {
    className: styles.filter,
    allowClear: true,
    prefix: /*#__PURE__*/React.createElement(IconSearch, null),
    value: filterText,
    onChange: setFilterText,
    placeholder: "Filter components"
  }), /*#__PURE__*/React.createElement(Divider, {
    className: styles.divider
  }), /*#__PURE__*/React.createElement("div", {
    className: styles.treeWrapper
  }, /*#__PURE__*/React.createElement(Tree, {
    autoExpandParent: true,
    blockNode: true,
    actionOnClick: ['select', 'expand'],
    treeData: routeInfo,
    selectedKeys: [componentId],
    renderTitle: node => {
      const key = node.dataRef.key;
      const isFolder = Array.isArray(node.dataRef.children);
      const eleText = /*#__PURE__*/React.createElement("span", {
        title: `${node.title}`,
        className: styles.treeNodeText
      }, node.title);
      return isFolder ? /*#__PURE__*/React.createElement("div", {
        className: styles.treeNode
      }, node.expanded ? /*#__PURE__*/React.createElement(IconFolderOpen, null) : /*#__PURE__*/React.createElement(IconFolder, null), eleText) : /*#__PURE__*/React.createElement(Link, {
        className: styles.treeNode,
        to: `/${key}`,
        onClick: () => onComponentChange(key)
      }, /*#__PURE__*/React.createElement(IconFile, null), eleText);
    }
  })));
}