// eslint-disable-next-line import/no-extraneous-dependencies
import React, { useContext } from 'react';
// eslint-disable-next-line import/no-extraneous-dependencies
import { Link } from 'react-router-dom';
import cs from 'classnames';
import { Avatar, Empty, Tag, Typography } from '@arco-design/web-react';
import { IconTag } from '@arco-design/web-react/icon';
import { WorkspaceContext } from "../workspaceContext";
import styles from "./workspaceOverview.module.scss";
const AVAILABLE_AVATAR_COLORS = ['#FF7D00', '#FADC19', '#9FDB1D', '#14C9C9', '#165DFF', '#722ED1'];
export function WorkspaceOverview() {
  const {
    components
  } = useContext(WorkspaceContext);
  const isEmpty = !(components !== null && components !== void 0 && components.length);
  return /*#__PURE__*/React.createElement("div", {
    className: cs(styles.workspaceOverview, {
      [styles.empty]: isEmpty
    })
  }, isEmpty ? /*#__PURE__*/React.createElement(Empty, {
    description: "No components found"
  }) : components.map(({
    id,
    name,
    packageName,
    version,
    author,
    description,
    labels
  }) => {
    const avatarText = author || 'Unknown';
    return /*#__PURE__*/React.createElement("div", {
      key: id,
      className: styles.componentCard
    }, /*#__PURE__*/React.createElement(Avatar, {
      className: styles.avatar,
      style: {
        background: AVAILABLE_AVATAR_COLORS[Math.floor(avatarText.length % AVAILABLE_AVATAR_COLORS.length)]
      }
    }, avatarText), /*#__PURE__*/React.createElement(Link, {
      title: name,
      className: styles.title,
      to: `/${id}`
    }, /*#__PURE__*/React.createElement("span", {
      className: styles.titleText
    }, name), /*#__PURE__*/React.createElement(Tag, {
      size: "small"
    }, "v", version)), /*#__PURE__*/React.createElement("div", {
      className: styles.packageName
    }, packageName), /*#__PURE__*/React.createElement(Typography.Paragraph, {
      className: styles.description,
      ellipsis: {
        rows: 3
      }
    }, description), /*#__PURE__*/React.createElement("div", {
      className: styles.labels
    }, /*#__PURE__*/React.createElement(IconTag, null), labels.join(' / ')));
  }));
}